# Playstation Game Title Finder

Small tool where, given a playstation game id, we attempt to find the title of this game. I've made this out of frustration after having to constantly check the game name online after leaving a few backups run all night, and forgetting which game is which.

For the time being, we only have access to ps3, psp, psm, psv and psx titles. Ps4 and ps5 will eventually come.
